@@ -28,7 +28,7 @@ class DBConnect():
             self.mongo_collection.insert_one(docu)
             return True
         except Exception as err:
-            logging.warning('MongoDB(组件)出现未知错误: {0}'.format(err))
+            logging.warning('MongoDB(组件)出现写入错误: {0}'.format(err))
             return False
 
     def does_it_exist(self, docu: dict) -> bool:
@@ -37,3 +37,14 @@ class DBConnect():
             return True
         else:
             return False
+
+    def update_docu(self, find_docu: dict, modify_docu: dict, many=False: bool) -> bool:
+        try:
+            if many:
+                self.mongo_collection.update_many(find_docu, modify_docu)
+            else:
+                self.mongo_collection.update_one(find_docu, modify_docu)
+            return True
+        except Exception as err:
+            logging.warning('MongoDB(组件)出现更新错误: {0}'.format(err))
+            return False
